==> galileo-0.10.0-py3-none-any.whl: galileo/resources/models/log_records_sort_clause.py <==
from typing import Any, Literal, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="LogRecordsSortClause")


@_attrs_define
class LogRecordsSortClause:
    """
    Attributes:
        column_id (str): ID of the column to sort.
        ascending (Union[Unset, bool]):  Default: True.
        sort_type (Union[Literal['column'], Unset]):  Default: 'column'.
    """

    column_id: str
    ascending: Union[Unset, bool] = True
    sort_type: Union[Literal["column"], Unset] = "column"
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        column_id = self.column_id

        ascending = self.ascending

        sort_type = self.sort_type

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"column_id": column_id})
        if ascending is not UNSET:
            field_dict["ascending"] = ascending
        if sort_type is not UNSET:
            field_dict["sort_type"] = sort_type

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        column_id = d.pop("column_id")

        ascending = d.pop("ascending", UNSET)

        sort_type = cast(Union[Literal["column"], Unset], d.pop("sort_type", UNSET))
        if sort_type != "column" and not isinstance(sort_type, Unset):
            raise ValueError(f"sort_type must match const 'column', got '{sort_type}'")

        log_records_sort_clause = cls(column_id=column_id, ascending=ascending, sort_type=sort_type)

        log_records_sort_clause.additional_properties = d
        return log_records_sort_clause

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> galileo-1.19.0-py3-none-any.whl: galileo/resources/models/log_records_sort_clause.py <==
from collections.abc import Mapping
from typing import Any, Literal, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="LogRecordsSortClause")


@_attrs_define
class LogRecordsSortClause:
    """
    Attributes:
        column_id (str): ID of the column to sort.
        ascending (Union[Unset, bool]):  Default: True.
        sort_type (Union[Literal['column'], Unset]):  Default: 'column'.
    """

    column_id: str
    ascending: Union[Unset, bool] = True
    sort_type: Union[Literal["column"], Unset] = "column"
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        column_id = self.column_id

        ascending = self.ascending

        sort_type = self.sort_type

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"column_id": column_id})
        if ascending is not UNSET:
            field_dict["ascending"] = ascending
        if sort_type is not UNSET:
            field_dict["sort_type"] = sort_type

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        column_id = d.pop("column_id")

        ascending = d.pop("ascending", UNSET)

        sort_type = cast(Union[Literal["column"], Unset], d.pop("sort_type", UNSET))
        if sort_type != "column" and not isinstance(sort_type, Unset):
            raise ValueError(f"sort_type must match const 'column', got '{sort_type}'")

        log_records_sort_clause = cls(column_id=column_id, ascending=ascending, sort_type=sort_type)

        log_records_sort_clause.additional_properties = d
        return log_records_sort_clause

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
